Learn R Programming

LimnoPalettes (version 0.1.0)

limno_palette: A Limnology palette generator

Description

These are a handful of color palettes inspired by lakes, rivers, streams and wetlands. .

Usage

limno_palette(name, n, type = c("discrete", "continuous"))

Arguments

name

Name of desired palette. Choices are: IowaSummer, PeriFA, Bloom1, Bloom2, SuperIce, FlatheadRocks, ShelburnePond, WetSoil,OrdRiver

n

Number of colors desired. All color schemes are derived from photos provided by contributors to this twitter thread. If omitted, uses all colours.

type

Either "continuous" or "discrete". Use continuous if you want to automatically interpolate between colours. @importFrom graphics rgb rect par image text

Value

A vector of colours.

Examples

Run this code
# NOT RUN {
limno_palette("IowaSummer")
limno_palette("Bloom2")
limno_palette("PeriFA",10,"continuous")
# }

Run the code above in your browser using DataLab