These are a handful of color palettes inspired by lakes, rivers, streams and wetlands. .
Usage
limno_palette(name, n, type = c("discrete", "continuous"))
Arguments
name
Name of desired palette. Choices are:
IowaSummer, PeriFA, Bloom1,
Bloom2, SuperIce, FlatheadRocks, ShelburnePond,
WetSoil,OrdRiver
n
Number of colors desired. All color
schemes are derived from photos provided by contributors to this
twitter thread.
If omitted, uses all colours.
type
Either "continuous" or "discrete". Use continuous if you want
to automatically interpolate between colours.
@importFrom graphics rgb rect par image text